/* includefile for AVI2YUV.C  version 0.97

   see avi2yuv.c for copyright notice
*/

#ifndef _AVI2YUV_H
#define _AVI2YUV_H

/* some usefull types */

typedef unsigned short WORD;
typedef unsigned long  DWORD;
typedef signed long    LONG;
typedef unsigned char  uCHAR;
typedef signed char    sCHAR;
typedef DWORD          FOURCC;             /* Type of FOUR Character Codes */

#define ChunkUnknown 0
#define ChunkLIST    1
#define ChunkHeader  2
#define ChunkVIDS    3
#define ChunkAUDS    4


/* Macro to convert expressions of form 'F','O','U','R' to
   numbers of type FOURCC: */

#define MAKEFOURCC(a,b,c,d) ( ((DWORD)a)      | (((DWORD)b)<< 8) | \
                             (((DWORD)c)<<16) | (((DWORD)d)<<24)  )

/* The only FOURCCs interpreted by this program: */

#define RIFFtag MAKEFOURCC('R','I','F','F')
#define LISTtag MAKEFOURCC('L','I','S','T')
#define AVItag  MAKEFOURCC('A','V','I',' ')
#define hdrltag MAKEFOURCC('h','d','r','l')
#define avihtag MAKEFOURCC('a','v','i','h')
#define strltag MAKEFOURCC('s','t','r','l')
#define strhtag MAKEFOURCC('s','t','r','h')
#define strftag MAKEFOURCC('s','t','r','f')
#define movitag MAKEFOURCC('m','o','v','i')
#define Tag00db MAKEFOURCC('0','0','d','b')
#define Tag00dc MAKEFOURCC('0','0','d','c')
#define Tag01wb MAKEFOURCC('0','1','w','b')

/* possible video formats */
#define TagMJPG MAKEFOURCC('M','J','P','G')
#define Tagmjpg MAKEFOURCC('m','j','p','g')
#define TagDIB  MAKEFOURCC('D','I','B',' ')
#define TagYVU9 MAKEFOURCC('Y','V','U','9')
#define TagY41P MAKEFOURCC('Y','4','1','P')
#define Tagdmb1 MAKEFOURCC('d','m','b','1')

/* FOURCC for wav output */
#define Tagfmt  MAKEFOURCC('f','m','t',' ')
#define Tagdata MAKEFOURCC('d','a','t','a')
#define TagWAVE MAKEFOURCC('W','A','V','E')

/* structs of the AVI header */

typedef struct {
  DWORD dwMicroSecPerFrame;
  DWORD dwMaxBytesPerSec;
  DWORD dwReserved1;
  DWORD dwFlags;
  DWORD dwTotalFrames;
  DWORD dwInitialFrames;
  DWORD dwStreams;
  DWORD dwSuggestedBufferSize;
  DWORD dwWidth;
  DWORD dwHeight;
  DWORD dwReserved2;
} tMainAVIHeader;

typedef struct {
  FOURCC fccType;
  FOURCC fccHandler;
  DWORD dwFlags;
  DWORD dwReserved1;
  DWORD dwInitialFrames;
  DWORD dwScale;
  DWORD dwRate;
  DWORD dwStart;
  DWORD dwLength;
  DWORD dwSuggestedBufferSize;
  DWORD dwQuality;
  DWORD dwSampleSize;
  DWORD dwReserved2;
} tAVIStreamHeader;

typedef struct {
  DWORD biSize;
  LONG  biWidth;
  LONG  biHeight;
  WORD  biPlanes;
  WORD  biBitCount;
  DWORD biCompression;
  DWORD biSizeImage;
  LONG  biXPelsPerMeter;
  LONG  biYPelsPerMeter;
  DWORD biClrUsed;
  DWORD biClrImportant;
} tBitmapInfoHeader;

typedef struct {
  WORD  wFormatTag;
  WORD  nChannels;
  DWORD nSamplesPerSec;
  DWORD nAvgBytesPerSec;
  WORD  nBlockAlign;
  WORD  wBitsPerSample;
  WORD  dbSize;
} tWaveFormatEx;

typedef struct {
  WORD  Width;
  WORD  Height;
  DWORD Frames;
  DWORD MSPerFrame;
  DWORD Scale;
  DWORD Rate;
  DWORD vHandler;
  DWORD vCompression;
  WORD  vPlanes;
  WORD  vBitsPerPixel;
  WORD  aFormat;
  WORD  aChannels;
  DWORD aSamplesPerSec;
  WORD  aBitsPerSample;
  WORD  vError;
} tGlobalInfo;

typedef struct {
  /* I HATE GNU it is IMPOSSIBLE to define a struct with 14 BYTE, FUCK IT */
  /* WORD  bfType; */
  DWORD bfSize;
  WORD  bfReserved1;
  WORD  bfReserved2;
  DWORD bfOffs;
} tBMPHeader;

typedef struct {
  FOURCC fccMainChunk;
  DWORD  dwFileLength;
  FOURCC fccType;
  FOURCC fccSubType;
  DWORD  dwLength;
  WORD   wFormat;
  WORD   wChannels;
  DWORD  dwSamplesPerSec;
  DWORD  dwBytesPerSec;
  WORD   wBytesPerSample;
  WORD   wBitsPerSample;
  FOURCC fccData;
  DWORD  dwDataLength;
} tWaveHeader;

typedef enum {FrameA, FrameB, FrameAB, BothFrame, FullFrame} FrameType;

#endif
